const request = require('./request.js')
module.exports = {
  // 授权相关
  Auth: {
    /**
     * 获取授权token
     * @param {string} appId 
     * @param {string} appSecret 
     */
    bcAuth(url, appId, appSecret, networkAPPID, networkYARN, isWX) {
      let params = {
        appId,
        appSecret,
        networkAPPID,
        networkYARN
      }
      if (isWX) {
        return request.wxpost(url, params, true)
      }
      return request.post(url, params, true)
    },
    /**
     * 获取用户的userOpenId
     * @param {string} userMobile 
     */
    userAuth(url, userMobile, token, appId, networkAPPID, networkYARN, isWX) {
      let params = {
        token,
        userMobile,
        appId,
        networkAPPID,
        networkYARN
      }
      if (isWX) {
        return request.wxpost(url, params)
      }
      return request.post(url, params)
    }
  },
  // UserCenter(用户相关)
  UserCenter: {
    /**
     * 发送手机验证码
     * @param {string} mobile 
     */
    sendMsgCode(url, mobile, type, token, appId, networkAPPID, networkYARN, isWX) {
      let params = {
        mobile,
        type,
        token,
        appId,
        networkAPPID,
        networkYARN
      }
      if (isWX) {
        return request.wxpost(url, params)
      }
      return request.post(url, params)
    },
    /**
     * 用户注册
     * @param {string} mobile 
     * @param {string} password 
     * @param {string} msgCode 
     */
    registerUser(url, mobile, password, msgCode, token, appId, networkAPPID, networkYARN, isWX) {
      let params = {
        mobile,
        password,
        msgCode,
        token,
        appId,
        networkAPPID,
        networkYARN
      }
      if (isWX) {
        return request.wxpost(url, params)
      }
      return request.post(url, params)
    },
    /**
     * 获取用户信息
     * @param {string} uid 
     */
    getUserInfo(url, userOpenID, token, appId, networkAPPID, networkYARN, isWX) {
      let params = {
        userOpenID,
        token,
        appId,
        networkAPPID,
        networkYARN
      }
      if (isWX) {
        return request.wxpost(url, params)
      }
      return request.post(url, params)
    },
    /**
     * 获取币的信息
     * @param {string} appId 
     */
    getCoinInfo(url, appId, token, networkAPPID, networkYARN, isWX) {
      let params = {
        appId,
        token,
        networkAPPID,
        networkYARN
      }
      if (isWX) {
        return request.wxpost(url, params)
      }
      return request.post(url, params)
    }
  },
  // wallet
  Wallet: {
    fetchAddress(url, token, appId, networkAPPID, networkYARN, isWX) {
      let params = {
        token,
        appId,
        networkAPPID,
        networkYARN
      }
      if (isWX) {
        return request.wxpost(url, params)
      }
      return request.post(url, params)
    },
    /**
     * 转账
     * @param {string} fromID 
     * @param {string} toID 
     * @param {string} count 
     * @param {string} token 
     * @param {string} appId 
     * @param {string} flag 
     */
    transfer(url, fromID, toID, count, token, appId, flag = '', networkAPPID, networkYARN, isWX) {
      let params = {
        fromID,
        toID,
        count,
        token,
        appId,
        flag,
        networkAPPID,
        networkYARN
      }
      if (isWX) {
        return request.wxpost(url, params)
      }
      return request.post(url, params)
    },
    /**
     * 从主账号奖励用户
     * @param {string}} toID 
     * @param {string} count 
     */
    giveCoin(url, toID, count, token, appId, flag = '', networkAPPID, networkYARN, isWX) {
      let params = {
        toID,
        count,
        token,
        appId,
        flag,
        networkAPPID,
        networkYARN
      }
      if (isWX) {
        return request.wxpost(url, params)
      }
      return request.post(url, params)
    },
    /**
     * 像用户索要币
     * @param {string} fromID 
     * @param {string} count 
     * @param {string} msgCode 
     */
    demandCoin(url, fromID, count, msgCode, token, appId, flag = '', networkAPPID, networkYARN, isWX) {
      let params = {
        fromID,
        count,
        msgCode,
        token,
        appId,
        flag,
        networkAPPID,
        networkYARN
      }
      if (isWX) {
        return request.wxpost(url, params)
      }
      return request.post(url, params)
    }
  }

}